<?php
/*
 * Plugin Name: Options for Twenty Nineteen
 * Version: 1.2.3
 * Plugin URI: https://webd.uk/options-for-twenty-nineteen/
 * Description: Adds various options to modify the default Wordpress theme Twenty Nineteen
 * Author: webd.uk
 * Author URI: https://webd.uk
 * Text Domain: options-for-twenty-nineteen
 */



if (!defined('ABSPATH')) {
    exit('This isn\'t the page you\'re looking for. Move along, move along.');
}



if (!class_exists('options_for_twenty_nineteen_class')) {

	class options_for_twenty_nineteen_class {

        public $oftn_upgrade_link;
        public $oftn_archive_description_shown;

		function __construct() {

            $this->oftn_upgrade_link = 'https://webd.uk/product/options-for-twenty-nineteen-upgrade/?url=' . (isset($_SERVER['HTTPS']) ? "https" : "http") . "://$_SERVER[HTTP_HOST]";
            $this->oftn_archive_description_shown = false;

            add_action('init', array($this, 'oftn_establish_version'));
            if (get_option('oftn_trial_date') == false) { add_action('init', array($this, 'oftn_start_trial')); }
            add_action('init', array($this, 'oftn_activate_upgrade'));
            add_action('customize_register', array($this, 'oftn_customize_register'), 999);
            add_filter('plugin_action_links_' . plugin_basename(__FILE__), array($this, 'oftn_add_plugin_settings_link'));
            add_action('wp_head' , array($this, 'oftn_header_output'));
            add_action('customize_controls_enqueue_scripts', array($this, 'oftn_enqueue_customizer_css'));
            add_action('customize_preview_init', array($this, 'oftn_enqueue_customize_preview_js'));
            add_action('customize_controls_enqueue_scripts', array($this, 'oftn_enqueue_customize_controls_js'));
            add_action('admin_notices', array($this, 'oftn_admin_notice'));
            add_action('wp_ajax_dismiss_oftn_notice_handler', array($this, 'oftn_ajax_notice_handler'));
            add_action('plugins_loaded', array($this, 'oftn_load_plugin_textdomain'));
            add_action('after_setup_theme', array($this, 'oftn_add_theme_support'), 11);
            add_action('load-post.php', array($this, 'oftn_theme_options_metabox_setup'));
            add_action('load-post-new.php', array($this, 'oftn_theme_options_metabox_setup'));

if ($this->oftn_request_permission('1.2.3', true) == true) {

            add_filter('twentynineteen_can_show_post_thumbnail', array($this, 'oftn_hide_featured_image'));

}

		}

		function oftn_establish_version() {

            if (get_option('oftn_free_version') === false) {

                $last_installed_version = get_user_meta(get_current_user_id(), 'oftn-notice-dismissed', true);

                if ($last_installed_version) {

                    if (version_compare($last_installed_version, '1.1.1') == -1) {

                        update_option('oftn_free_version', $last_installed_version);

                    } else {

                        update_option('oftn_free_version', '1.0');

                    }

                } else {

                        update_option('oftn_free_version', '1.0');

                }

            }

		}

		function oftn_add_plugin_settings_link($links) {

			$settings_links[] = '<a href="' . oftn_home_root() . 'wp-admin/customize.php" title="' . __('Settings', 'options-for-twenty-nineteen') . '">' . __('Settings', 'options-for-twenty-nineteen') . '</a>';

            if (get_option('oftn_purchased') == false) {

                $settings_links[] = '<a href="' . $this->oftn_upgrade_link . '" title="' . __('Upgrade Options for Twenty Nineteen', 'options-for-twenty-nineteen') . '" style="color: orange; font-weight: bold;">' . __('Upgrade', 'options-for-twenty-nineteen') . '</a>';
                $settings_links[] = '<a href="' . wp_nonce_url('?activate-oftn=true', 'oftn_activate') . '" id="oftn_activate_upgrade" title="' . __('Activate Upgrade', 'options-for-twenty-nineteen') . '" onclick="jQuery(this).append(&#39; <img src=&#34;/wp-admin/images/loading.gif&#34; style=&#34;float: none; width: auto; height: auto;&#34; />&#39;); setTimeout(function(){document.getElementById(\'oftn_activate_upgrade\').removeAttribute(\'href\');},1); return true;">' . __('Activate Upgrade', 'options-for-twenty-nineteen') . '</a>';

            } else {

                $settings_links[] = '<strong style="color: green; display: inline;">' . __('Upgraded', 'options-for-twenty-nineteen') . '</strong>';

            }

			return array_merge($settings_links, $links);

		}

        function oftn_start_trial() {

        	if (is_admin() && isset($_GET['oftn-start-trial']) && $_GET['oftn-start-trial'] == 'true' && get_option('oftn_trial_date') == false && check_admin_referer('oftn_start_trial')) {

                update_option('oftn_trial_date', time());

                add_action('admin_notices', array($this, 'oftn_trial_started_notice'));

        	}

        }

        function oftn_trial_started_notice() {

?>

<div class="notice notice-info">

<p><strong><?php _e('Options for Twenty Nineteen Trial Started', 'options-for-twenty-nineteen'); ?></strong><br />
<?php
        _e('Your free 7 day trial of Options for Twenty Nineteen has started.', 'options-for-twenty-nineteen');
?>
</p>

</div>

<?php

        }

        function oftn_activate_upgrade() {

        	if (is_admin() && isset($_GET['activate-oftn']) && $_GET['activate-oftn'] == 'true' && check_admin_referer('oftn_activate')) {

                $http_url = 'https://webd.uk/activate/';
                $http_args = array(
                    'timeout' => 15,
                    'body' => array(
                        'url' => ((isset($_SERVER['HTTPS']) ? "https" : "http") . '://' . $_SERVER['HTTP_HOST']),
                        'plugin' => 'options-for-twenty-nineteen'
                    )
                );
                $request = wp_remote_post( $http_url, $http_args );

                if (is_wp_error($request)) {

					delete_option('oftn_purchased');
                    add_action('admin_notices', array($this, 'oftn_upgrade_failed_cannot_connect_notice'));

                } elseif (isset($request['body']) && $request['body'] == 'True') {

					update_option('oftn_purchased', true);

				} else {

					delete_option('oftn_purchased');
                    add_action('admin_notices', array($this, 'oftn_upgrade_failed_notice'));

				}

        	}

        }

        function oftn_upgrade_failed_notice() {

?>

<div class="notice notice-error">

<p><strong><?php _e('Options for Twenty Nineteen Upgrade Activation Error', 'options-for-twenty-nineteen'); ?></strong><br />
<?= sprintf(wp_kses(__('Please <a href="%s">purchase an upgrade</a> first. If you have already purchased an upgrade for this plugin, please contact us so we can investigate the issue.', 'options-for-twenty-nineteen'), array('a' => array('href' => array()))), esc_url($this->oftn_upgrade_link)); ?>
</p>

</div>

<?php

        }

        function oftn_upgrade_failed_cannot_connect_notice() {

?>

<div class="notice notice-error">

<p><strong><?php _e('Options for Twenty Nineteen Upgrade Activation Error', 'options-for-twenty-nineteen'); ?></strong><br />
<?php
        _e('The upgrade has failed because your website cannot connect to webd.uk to confirm your purchase. Please contact your Service provider to ask them to unblock webd.uk and if they cannot help you please contact us so we can investigate further.', 'options-for-twenty-nineteen');
?>
</p>

</div>

<?php

        }

        function oftn_customize_register($wp_customize) {


            $support_url = 'https://wordpress.org/support/plugin/options-for-twenty-nineteen';
            $default_description = sprintf(wp_kses(__('If you have any requests for new options, please <a href="%s">let us know in the support forum</a>.', 'options-for-twenty-nineteen'), array('a' => array('href' => array()))), esc_url($support_url));
            $upgrade_link = '<a href="' . $this->oftn_upgrade_link . '" title="' . __('Upgrade Options for Twenty Nineteen', 'options-for-twenty-nineteen') . '">' . __('Upgrade Options for Twenty Nineteen', 'options-for-twenty-nineteen') . '</a>';

            if (!get_option('oftn_trial_date')) {

                $upgrade_link .= ' or <a href="' . wp_nonce_url(oftn_home_root() . 'wp-admin/plugins.php?oftn-start-trial=true', 'oftn_start_trial') . '" title="' . __('Start Free Trial', 'options-for-twenty-nineteen') . '">' . __('start a 7 day free trail', 'options-for-twenty-nineteen') . '</a>';

            }

            $upgrade_nag = $upgrade_link . __(' to activate this option.', 'options-for-twenty-nineteen');

if (get_option('oftn_purchased') == false) {

    if (get_option('oftn_trial_date') && time() < (strtotime('+1 week', get_option('oftn_trial_date')))) {

        $expiring_in = ceil(abs((strtotime('+1 week', get_option('oftn_trial_date'))) - time())/60/60/24);
        $expiring_text = '<span class="attention">' . sprintf(_n('Options for Twenty Nineteen plugin trial expires in less than %s day!', 'Options for Twenty Nineteen plugin trial expires in less than %s days!', $expiring_in, 'options-for-twenty-nineteen'), $expiring_in) . '</span>';
        $section_description = '<strong>' . $expiring_text . '</strong>' . ' ' . $upgrade_link . ' ' . __('to keep using all the options after that time.', 'options-for-twenty-nineteen');

    } else {

        $section_description = '';

    }

} else {

    $section_description = $default_description;

}



            $wp_customize->add_section('oftn_general', array(
                'title'     => __('General Options', 'options-for-twenty-nineteen'),
                'description'  => __('Use these options to customise the overall site design.', 'options-for-twenty-nineteen') . ' ' . $section_description,
                'priority'     => 0
            ));

            $wp_customize->add_setting('hide_dashes', array(
                'default'           => false,
                'type'              => 'theme_mod',
                'transport'         => 'refresh',
                'sanitize_callback' => array($this, 'oftn_sanitize_boolean')
            ));
            $wp_customize->add_control('hide_dashes', array(
                'label'         => __('Hide Dashes', 'options-for-twenty-nineteen'),
                'description'   => __('Hide the dashes that appear through the theme.', 'options-for-twenty-nineteen'),
                'section'       => 'oftn_general',
                'settings'      => 'hide_dashes',
                'type'          => 'checkbox'
            ));



            $wp_customize->add_section('oftn_header', array(
                'title'     => __('Header Options', 'options-for-twenty-nineteen'),
                'description'  => __('Use these options to customise the header.', 'options-for-twenty-nineteen') . ' ' . $section_description,
                'priority'     => 0
            ));

            $control_label = __('Show Featured Image on Posts Page', 'options-for-twenty-nineteen');
            $control_description = __('Show the featured image selected on the page chosen to be the posts page.', 'options-for-twenty-nineteen');

if ($this->oftn_request_permission('1.0.8') == true) {

            $wp_customize->add_setting('show_featured_image_on_pasts_page', array(
                'default'           => false,
                'type'              => 'theme_mod',
                'transport'         => 'refresh',
                'sanitize_callback' => array($this, 'oftn_sanitize_boolean')
            ));
            $wp_customize->add_control('show_featured_image_on_pasts_page', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftn_header',
                'settings'      => 'show_featured_image_on_pasts_page',
                'type'          => 'checkbox'
            ));

} else {

		    $wp_customize->add_control(new oftn_WP_Customize_Notice_Control($wp_customize, 'show_featured_image_on_pasts_page', array(
                'label'         => $control_label,
                'description'   => $control_description . ' ' . $upgrade_nag,
                'section'       => 'oftn_header',
				'settings'      => array()
			)));

}

            $control_label = __('Show Title on Posts Page', 'options-for-twenty-nineteen');
            $control_description = __('Show the page title on the page chosen to be the posts page.', 'options-for-twenty-nineteen');

if ($this->oftn_request_permission('1.1.8') == true) {

            $wp_customize->add_setting('show_title_on_pasts_page', array(
                'default'           => false,
                'type'              => 'theme_mod',
                'transport'         => 'refresh',
                'sanitize_callback' => array($this, 'oftn_sanitize_boolean')
            ));
            $wp_customize->add_control('show_title_on_pasts_page', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftn_header',
                'settings'      => 'show_title_on_pasts_page',
                'type'          => 'checkbox'
            ));

} else {

		    $wp_customize->add_control(new oftn_WP_Customize_Notice_Control($wp_customize, 'show_title_on_pasts_page', array(
                'label'         => $control_label,
                'description'   => $control_description . ' ' . $upgrade_nag,
                'section'       => 'oftn_header',
				'settings'      => array()
			)));

}

            $wp_customize->add_setting('logo_width', array(
                'default'       => '64',
                'type'          => 'theme_mod',
                'transport'     => 'refresh',
                'sanitize_callback' => array($this, 'oftn_sanitize_integer')
            ));
            $wp_customize->add_control('logo_width', array(
                'label'         => __('Logo Width', 'options-for-twenty-nineteen'),
                'description'   => __('Set the width of the logo on large screens.', 'options-for-twenty-nineteen'),
                'section'       => 'oftn_header',
                'settings'      => 'logo_width',
                'type'          => 'range',
                'input_attrs' => array(
                    'min'   => 1,
                    'max'   => 190,
                    'step'  => 1
                )
            ));

            $control_label = __('Move Logo Above Title', 'options-for-twenty-nineteen');
            $control_description = __('Repositions the logo above the site title. This option will override the above setting and show the full size logo.', 'options-for-twenty-nineteen');

if ($this->oftn_request_permission('1.1.3') == true) {

            $wp_customize->add_setting('reposition_logo', array(
                'default'           => false,
                'type'              => 'theme_mod',
                'transport'         => 'refresh',
                'sanitize_callback' => array($this, 'oftn_sanitize_boolean')
            ));
            $wp_customize->add_control('reposition_logo', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftn_header',
                'settings'      => 'reposition_logo',
                'type'          => 'checkbox'
            ));

} else {

		    $wp_customize->add_control(new oftn_WP_Customize_Notice_Control($wp_customize, 'reposition_logo', array(
                'label'         => $control_label,
                'description'   => $control_description . ' ' . $upgrade_nag,
                'section'       => 'oftn_header',
				'settings'      => array()
			)));

}

            $control_label = __('Logo Alignment', 'options-for-twenty-nineteen');
            $control_description = __('Align the logo to the left, center or right. For use with the above option only.', 'options-for-twenty-nineteen');

if ($this->oftn_request_permission('1.1.3') == true) {

            $wp_customize->add_setting('logo_align', array(
                'default'       => '',
                'type'          => 'theme_mod',
                'transport'     => 'postMessage',
                'sanitize_callback' => array($this, 'oftn_sanitize_slug_options')
            ));
            $wp_customize->add_control('logo_align', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftn_header',
                'settings'      => 'logo_align',
                'type'          => 'select',
                'choices'       => array(
                    '' => __('Left', 'options-for-twenty-nineteen'),
                    'center' => __('Center', 'options-for-twenty-nineteen'),
                    'right' => __('Right', 'options-for-twenty-nineteen')
                )
            ));

} else {

		    $wp_customize->add_control(new oftn_WP_Customize_Notice_Control($wp_customize, 'logo_align', array(
                'label'         => $control_label,
                'description'   => $control_description . ' ' . $upgrade_nag,
                'section'       => 'oftn_header',
				'settings'      => array()
			)));

}

            $wp_customize->add_setting('remove_logo_background', array(
                'default'           => false,
                'type'              => 'theme_mod',
                'transport'         => 'postMessage',
                'sanitize_callback' => array($this, 'oftn_sanitize_boolean')
            ));
            $wp_customize->add_control('remove_logo_background', array(
                'label'         => __('Remove Logo Background', 'options-for-twenty-nineteen'),
                'description'   => __('Remove the white background from the logo.', 'options-for-twenty-nineteen'),
                'section'       => 'oftn_header',
                'settings'      => 'remove_logo_background',
                'type'          => 'checkbox'
            ));

            $control_label = __('Remove Logo Circle Mask', 'options-for-twenty-nineteen');
            $control_description = __('Removes the circle effect and allows the logo to be its own shape.', 'options-for-twenty-nineteen');

if ($this->oftn_request_permission('1.1.1') == true) {

            $wp_customize->add_setting('remove_logo_border_radius', array(
                'default'           => false,
                'type'              => 'theme_mod',
                'transport'         => 'refresh',
                'sanitize_callback' => array($this, 'oftn_sanitize_boolean')
            ));
            $wp_customize->add_control('remove_logo_border_radius', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftn_header',
                'settings'      => 'remove_logo_border_radius',
                'type'          => 'checkbox'
            ));

} else {

		    $wp_customize->add_control(new oftn_WP_Customize_Notice_Control($wp_customize, 'remove_logo_border_radius', array(
                'label'         => $control_label,
                'description'   => $control_description . ' ' . $upgrade_nag,
                'section'       => 'oftn_header',
				'settings'      => array()
			)));

}

            $control_label = __('Hide Site Title', 'options-for-twenty-nineteen');
            $control_description = __('Hides the site title.', 'options-for-twenty-nineteen');

if ($this->oftn_request_permission('1.1.7') == true) {

            $wp_customize->add_setting('hide_site_title', array(
                'default'           => false,
                'type'              => 'theme_mod',
                'transport'         => 'refresh',
                'sanitize_callback' => array($this, 'oftn_sanitize_boolean')
            ));
            $wp_customize->add_control('hide_site_title', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftn_header',
                'settings'      => 'hide_site_title',
                'type'          => 'checkbox'
            ));

} else {

		    $wp_customize->add_control(new oftn_WP_Customize_Notice_Control($wp_customize, 'hide_site_title', array(
                'label'         => $control_label,
                'description'   => $control_description . ' ' . $upgrade_nag,
                'section'       => 'oftn_header',
				'settings'      => array()
			)));

}

            $wp_customize->add_setting('site_title_align', array(
                'default'       => '',
                'type'          => 'theme_mod',
                'transport'     => 'postMessage',
                'sanitize_callback' => array($this, 'oftn_sanitize_slug_options')
            ));
            $wp_customize->add_control('site_title_align', array(
                'label'         => __('Site Title Alignment', 'options-for-twenty-nineteen'),
                'description'   => __('Align the site title to the left, center or right.', 'options-for-twenty-nineteen'),
                'section'       => 'oftn_header',
                'settings'      => 'site_title_align',
                'type'          => 'select',
                'choices'       => array(
                    '' => __('Left', 'options-for-twenty-nineteen'),
                    'center' => __('Center', 'options-for-twenty-nineteen'),
                    'right' => __('Right', 'options-for-twenty-nineteen')
                )
            ));

            $control_label = __('Hide Site Description', 'options-for-twenty-nineteen');
            $control_description = __('Hides the site description.', 'options-for-twenty-nineteen');

if ($this->oftn_request_permission('1.1.7') == true) {

            $wp_customize->add_setting('hide_site_description', array(
                'default'           => false,
                'type'              => 'theme_mod',
                'transport'         => 'refresh',
                'sanitize_callback' => array($this, 'oftn_sanitize_boolean')
            ));
            $wp_customize->add_control('hide_site_description', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftn_header',
                'settings'      => 'hide_site_description',
                'type'          => 'checkbox'
            ));

} else {

		    $wp_customize->add_control(new oftn_WP_Customize_Notice_Control($wp_customize, 'hide_site_description', array(
                'label'         => $control_label,
                'description'   => $control_description . ' ' . $upgrade_nag,
                'section'       => 'oftn_header',
				'settings'      => array()
			)));

}

            $wp_customize->add_setting('site_description_align', array(
                'default'       => '',
                'type'          => 'theme_mod',
                'transport'     => 'postMessage',
                'sanitize_callback' => array($this, 'oftn_sanitize_slug_options')
            ));
            $wp_customize->add_control('site_description_align', array(
                'label'         => __('Site Description Alignment', 'options-for-twenty-nineteen'),
                'description'   => __('Align the site description to the left, center or right.', 'options-for-twenty-nineteen'),
                'section'       => 'oftn_header',
                'settings'      => 'site_description_align',
                'type'          => 'select',
                'choices'       => array(
                    '' => __('Left', 'options-for-twenty-nineteen'),
                    'center' => __('Center', 'options-for-twenty-nineteen'),
                    'right' => __('Right', 'options-for-twenty-nineteen')
                )
            ));



            $wp_customize->add_section('oftn_navigation', array(
                'title'        => __('Nav Options', 'options-for-twenty-nineteen'),
                'description'  => __('Use these options to customise the navigation.', 'options-for-twenty-nineteen') . ' ' . $section_description,
                'priority'     => 0
            ));

            $wp_customize->add_setting('navigation_font_size', array(
                'default'           => 1125,
                'type'              => 'theme_mod',
                'transport'         => 'postMessage',
                'sanitize_callback' => array($this, 'oftn_sanitize_integer')
            ));
            $wp_customize->add_control('navigation_font_size', array(
                'label'         => __('Navigation Font Size', 'options-for-twenty-nineteen'),
                'description'   => __('Change the font size of the navigation menu.', 'options-for-twenty-nineteen'),
                'section'       => 'oftn_navigation',
                'settings'      => 'navigation_font_size',
                'type'          => 'range',
                'input_attrs' => array(
                    'min'   => 875,
                    'max'   => 1375,
                    'step'  => 25
                ),
            ));



            $wp_customize->add_section('oftn_content', array(
                'title'     => __('Content Options', 'options-for-twenty-nineteen'),
                'description'  => __('Use these options to customise the content.', 'options-for-twenty-nineteen') . ' ' . $section_description,
                'priority'     => 0
            ));

            $control_label = __('Implement Yoast SEO Breadcrumbs', 'options-for-twenty-nineteen');
            $control_description = sprintf(wp_kses(__('Inject <a href="%s">Yoast SEO</a> breadcrumbs above and / or below single post and page content.', 'options-for-twenty-nineteen'), array('a' => array('href' => array()))), esc_url(oftn_home_root() . 'wp-admin/plugin-install.php?s=wordpress-seo&tab=search&type=term'));

if ($this->oftn_request_permission('1.2.1') == true) {

            $wp_customize->add_setting('implement_yoast_breadcrumbs', array(
                'default'       => '',
                'type'          => 'theme_mod',
                'transport'     => 'refresh',
                'sanitize_callback' => array($this, 'oftn_sanitize_slug_options')
            ));
            $wp_customize->add_control('implement_yoast_breadcrumbs', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftn_content',
                'settings'      => 'implement_yoast_breadcrumbs',
                'type'          => 'select',
                'choices'       => array(
                    '' => __('Disable Breadcrumbs', 'options-for-twenty-nineteen'),
                    'top' => __('Above Content', 'options-for-twenty-nineteen'),
                    'bottom' => __('Below Content', 'options-for-twenty-nineteen'),
                    'both' => __('Above and Below Content', 'options-for-twenty-nineteen')
                )
            ));

} else {

		    $wp_customize->add_control(new oftn_WP_Customize_Notice_Control($wp_customize, 'implement_yoast_breadcrumbs', array(
                'label'         => $control_label,
                'description'   => $control_description . ' ' . $upgrade_nag,
                'section'       => 'oftn_content',
				'settings'      => array()
			)));

}

            $control_label = __('Show Archive Description', 'options-for-twenty-nineteen');
            $control_description = __('Show the tag or category description on archive pages.', 'options-for-twenty-nineteen');

if ($this->oftn_request_permission('1.0.2') == true) {

            $wp_customize->add_setting('show_archive_description', array(
                'default'           => false,
                'type'              => 'theme_mod',
                'transport'         => 'refresh',
                'sanitize_callback' => array($this, 'oftn_sanitize_boolean')
            ));
            $wp_customize->add_control('show_archive_description', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftn_content',
                'settings'      => 'show_archive_description',
                'type'          => 'checkbox'
            ));

} else {

		    $wp_customize->add_control(new oftn_WP_Customize_Notice_Control($wp_customize, 'show_archive_description', array(
                'label'         => $control_label,
                'description'   => $control_description . ' ' . $upgrade_nag,
                'section'       => 'oftn_content',
				'settings'      => array()
			)));

}

            $control_label = __('Show Full Content in Archive', 'options-for-twenty-nineteen');
            $control_description = __('Show the full post content rather than an excerpt in archive pages.', 'options-for-twenty-nineteen');

if ($this->oftn_request_permission('1.0.6') == true) {

            $wp_customize->add_setting('show_full_content_in_archive', array(
                'default'           => false,
                'type'              => 'theme_mod',
                'transport'         => 'refresh',
                'sanitize_callback' => array($this, 'oftn_sanitize_boolean')
            ));
            $wp_customize->add_control('show_full_content_in_archive', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftn_content',
                'settings'      => 'show_full_content_in_archive',
                'type'          => 'checkbox'
            ));

} else {

		    $wp_customize->add_control(new oftn_WP_Customize_Notice_Control($wp_customize, 'show_full_content_in_archive', array(
                'label'         => $control_label,
                'description'   => $control_description . ' ' . $upgrade_nag,
                'section'       => 'oftn_content',
				'settings'      => array()
			)));

}

            $wp_customize->add_setting('post_meta_location', array(
                'default'       => '',
                'type'          => 'theme_mod',
                'transport'     => 'postMessage',
                'sanitize_callback' => array($this, 'oftn_sanitize_slug_options')
            ));
            $wp_customize->add_control('post_meta_location', array(
                'label'         => __('Post Date / Author Location', 'options-for-twenty-nineteen'),
                'description'   => __('Sets the postion of the post date and author line.', 'options-for-twenty-nineteen'),
                'section'       => 'oftn_content',
                'settings'      => 'post_meta_location',
                'type'          => 'select',
                'choices'       => array(
                    'none' => __('None', 'options-for-twenty-nineteen'),
                    'above' => __('Above post content', 'options-for-twenty-nineteen'),
                    'below' => __('Below post content', 'options-for-twenty-nineteen'),
                    '' => __('Above and below', 'options-for-twenty-nineteen')
                )
            ));

            $wp_customize->add_setting('remove_posted_on', array(
                'default'           => false,
                'type'              => 'theme_mod',
                'transport'         => 'postMessage',
                'sanitize_callback' => array($this, 'oftn_sanitize_boolean')
            ));
            $wp_customize->add_control('remove_posted_on', array(
                'label'         => __('Hide Post Dates', 'options-for-twenty-nineteen'),
                'description'   => __('Prevents Wordpress from displaying the date of a post.', 'options-for-twenty-nineteen'),
                'section'       => 'oftn_content',
                'settings'      => 'remove_posted_on',
                'type'          => 'checkbox'
            ));

            $wp_customize->add_setting('remove_author', array(
                'default'           => false,
                'type'              => 'theme_mod',
                'transport'         => 'postMessage',
                'sanitize_callback' => array($this, 'oftn_sanitize_boolean')
            ));
            $wp_customize->add_control('remove_author', array(
                'label'         => __('Hide Post Author', 'options-for-twenty-nineteen'),
                'description'   => __('Hides the author of a post in the browser.', 'options-for-twenty-nineteen'),
                'section'       => 'oftn_content',
                'settings'      => 'remove_author',
                'type'          => 'checkbox'
            ));

            $control_label = __('Activate Jetpack Infinite Scroll', 'options-for-twenty-nineteen');
            $control_description = __('Turns on infinite scroll when using Jetpack, remember not to use footer widgets as they won\'t be accessible.', 'options-for-twenty-nineteen');

if ($this->oftn_request_permission('1.0.4') == true) {

            $wp_customize->add_setting('infinite_scroll', array(
                'default'           => false,
                'type'              => 'theme_mod',
                'transport'         => 'refresh',
                'sanitize_callback' => array($this, 'oftn_sanitize_boolean')
            ));
            $wp_customize->add_control('infinite_scroll', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftn_content',
                'settings'      => 'infinite_scroll',
                'type'          => 'checkbox'
            ));

} else {

		    $wp_customize->add_control(new oftn_WP_Customize_Notice_Control($wp_customize, 'infinite_scroll', array(
                'label'         => $control_label,
                'description'   => $control_description . ' ' . $upgrade_nag,
                'section'       => 'oftn_content',
				'settings'      => array()
			)));

}



            $wp_customize->add_section('oftn_footer', array(
                'title'     => __('Footer Options', 'options-for-twenty-nineteen'),
                'description'  => __('Use these options to customise the footer.', 'options-for-twenty-nineteen') . ' ' . $section_description,
                'priority'     => 0
            ));

            $wp_customize->add_setting('remove_powered_by_wordpress', array(
                'default'       => false,
                'type'          => 'theme_mod',
                'transport'     => 'refresh',
                'sanitize_callback' => array($this, 'oftn_sanitize_boolean')
            ));
            $wp_customize->add_control('remove_powered_by_wordpress', array(
                'label'         => __('Remove Powered by WordPress', 'options-for-twenty-nineteen'),
                'description'   => __('Removes the "Proudly powered by WordPress" text displayed in the website footer.', 'options-for-twenty-nineteen'),
                'section'       => 'oftn_footer',
                'settings'      => 'remove_powered_by_wordpress',
                'type'          => 'checkbox'
            ));

            $control_label = __('Replace "Powered by" Text', 'options-for-twenty-nineteen');
            $control_description = __('Provide alternate text to replace "Proudly powered by Wordpress".', 'options-for-twenty-nineteen');

if ($this->oftn_request_permission('1.1.6') == true) {

            $wp_customize->add_setting('replace_powered_by_wordpress', array(
                'default'           => '',
                'type'              => 'theme_mod',
                'transport'         => 'refresh',
                'sanitize_callback' => array($this, 'oftn_sanitize_html')
            ));
            $wp_customize->add_control('replace_powered_by_wordpress', array(
                'label'         => $control_label,
                'description'   => $control_description,
                'section'       => 'oftn_footer',
                'settings'      => 'replace_powered_by_wordpress',
                'type'          => 'text'
            ));

} else {

		    $wp_customize->add_control(new oftn_WP_Customize_Notice_Control($wp_customize, 'replace_powered_by_wordpress', array(
                'label'         => $control_label,
                'description'   => $control_description . ' ' . $upgrade_nag,
                'section'       => 'oftn_footer',
				'settings'      => array()
			)));

}



            $wp_customize->add_setting('hex_primary_color', array(
                'default'       => '',
                'type'          => 'theme_mod',
                'transport'     => 'postMessage',
                'sanitize_callback' => 'sanitize_hex_color'
            ));
            $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'hex_primary_color', array(
                'label'         => __('Hex Primary Colour', 'options-for-twenty-nineteen'),
                'description'   => __('Set the hue, saturation and lightness of the primary colour using a HEX control.', 'options-for-twenty-nineteen'),
                'section'       => 'colors',
            	'settings'      => 'hex_primary_color'
            )));

            $wp_customize->add_setting('opacity_level', array(
                'default'       => '71',
                'type'          => 'theme_mod',
                'transport'     => 'refresh',
                'sanitize_callback' => array($this, 'oftn_sanitize_integer')
            ));
            $wp_customize->add_control('opacity_level', array(
                'label'         => __('Opacity Level', 'options-for-twenty-nineteen'),
                'description'   => __('Adjust the default opacity level on featured images when not using the filter.', 'options-for-twenty-nineteen'),
                'section'       => 'colors',
                'settings'      => 'opacity_level',
                'type'          => 'range',
                'input_attrs' => array(
                    'min'   => 1,
                    'max'   => 101,
                    'step'  => 1
                )
            ));

            $wp_customize->add_setting('saturation_level', array(
                'default'       => '101',
                'type'          => 'theme_mod',
                'transport'     => 'refresh',
                'sanitize_callback' => array($this, 'oftn_sanitize_integer')
            ));
            $wp_customize->add_control('saturation_level', array(
                'label'         => __('Saturation Level', 'options-for-twenty-nineteen'),
                'description'   => __('Adjust the default saturation level.', 'options-for-twenty-nineteen'),
                'section'       => 'colors',
                'settings'      => 'saturation_level',
                'type'          => 'range',
                'input_attrs' => array(
                    'min'   => 1,
                    'max'   => 101,
                    'step'  => 1
                )
            ));

            $wp_customize->add_setting('lightness_level', array(
                'default'       => '34',
                'type'          => 'theme_mod',
                'transport'     => 'refresh',
                'sanitize_callback' => array($this, 'oftn_sanitize_integer')
            ));
            $wp_customize->add_control('lightness_level', array(
                'label'         => __('Lightness Level', 'options-for-twenty-nineteen'),
                'description'   => __('Adjust the default lightness level.', 'options-for-twenty-nineteen'),
                'section'       => 'colors',
                'settings'      => 'lightness_level',
                'type'          => 'range',
                'input_attrs' => array(
                    'min'   => 1,
                    'max'   => 101,
                    'step'  => 1
                )
            ));

            $wp_customize->add_setting('hover_lightness_level', array(
                'default'       => '24',
                'type'          => 'theme_mod',
                'transport'     => 'refresh',
                'sanitize_callback' => array($this, 'oftn_sanitize_integer')
            ));
            $wp_customize->add_control('hover_lightness_level', array(
                'label'         => __('Hover Lightness Level', 'options-for-twenty-nineteen'),
                'description'   => __('Adjust the default hover lightness level.', 'options-for-twenty-nineteen'),
                'section'       => 'colors',
                'settings'      => 'hover_lightness_level',
                'type'          => 'range',
                'input_attrs' => array(
                    'min'   => 1,
                    'max'   => 101,
                    'step'  => 1
                )
            ));

            $wp_customize->add_setting('selection_saturation_level', array(
                'default'       => '51',
                'type'          => 'theme_mod',
                'transport'     => 'refresh',
                'sanitize_callback' => array($this, 'oftn_sanitize_integer')
            ));
            $wp_customize->add_control('selection_saturation_level', array(
                'label'         => __('Selection Saturation Level', 'options-for-twenty-nineteen'),
                'description'   => __('Adjust the default selection saturation level.', 'options-for-twenty-nineteen'),
                'section'       => 'colors',
                'settings'      => 'selection_saturation_level',
                'type'          => 'range',
                'input_attrs' => array(
                    'min'   => 1,
                    'max'   => 101,
                    'step'  => 1
                )
            ));

            $wp_customize->add_setting('selection_lightness_level', array(
                'default'       => '91',
                'type'          => 'theme_mod',
                'transport'     => 'refresh',
                'sanitize_callback' => array($this, 'oftn_sanitize_integer')
            ));
            $wp_customize->add_control('selection_lightness_level', array(
                'label'         => __('Selection Lightness Level', 'options-for-twenty-nineteen'),
                'description'   => __('Adjust the default selection lightness level.', 'options-for-twenty-nineteen'),
                'section'       => 'colors',
                'settings'      => 'selection_lightness_level',
                'type'          => 'range',
                'input_attrs' => array(
                    'min'   => 1,
                    'max'   => 101,
                    'step'  => 1
                )
            ));

        }

        function oftn_sanitize_boolean($input) {

            if (isset($input)) {

                if ($input == true) {

                    return true;

                } else {

                    return false;

                }

            } else {

                    return false;

            }

        }

        function oftn_sanitize_integer($input) {

            return absint($input);

        }

        function oftn_sanitize_slug_options($input, $setting) {

            $input =  sanitize_key($input);
            $choices = $setting->manager->get_control($setting->id)->choices;

            return (array_key_exists($input, $choices) ? $input : $setting->default);

        }

        function oftn_sanitize_text_options($input, $setting) {

            $choices = $setting->manager->get_control($setting->id)->choices;

            return (array_key_exists($input, $choices) ? $input : $setting->default);

        }

        function oftn_sanitize_html($input) {

            return wp_kses_post($input);

        }

        function oftn_header_output() {

?>
<!--Customizer CSS--> 
<style type="text/css">
.site-logo .custom-logo-link {
    height: auto;
}
.site-logo .custom-logo-link .custom-logo {
	display: block;
}
<?php

if ($this->oftn_request_permission('1.2.2', true) == true) {

            if ((is_page() || is_single()) && get_post_meta(get_the_ID(), 'oftn_hide_title', true) == '1') {

?>
#main article:first-of-type .entry-title {
    display: none;
}
<?php

            }

}

            if (get_theme_mod('hide_dashes')) {

?>
.site-description:before,
h1:not(.site-title):before, h2:before,
.entry .entry-title:before,
.comments-area .comments-title-wrap .comments-title:before,
.post-navigation .nav-links .nav-previous .meta-nav:before {
	display: none;
}
<?php

            }

if ($this->oftn_request_permission('1.0.8', true) == true) {

            if (get_theme_mod('show_featured_image_on_pasts_page') && is_home() && get_option('page_for_posts')) {

                add_action('get_template_part_template-parts/header/site', array($this, 'oftn_show_featured_image_on_pasts_page'));

            }

}

if ($this->oftn_request_permission('1.1.8', true) == true) {

            if (!get_theme_mod('show_featured_image_on_pasts_page') && get_theme_mod('show_title_on_pasts_page') && is_home() && get_option('page_for_posts')) {

                add_action('get_template_part_template-parts/header/site', array($this, 'oftn_show_title_on_pasts_page'));

            }

}

            $mod = get_theme_mod('logo_width');

            if ($mod) {

?>
@media only screen and (min-width: 768px) {
	.site-logo .custom-logo-link {
        width: <?= $mod; ?>px;
    }
}
<?php

            }

if ($this->oftn_request_permission('1.1.3', true) == true) {

            if (get_theme_mod('reposition_logo')) {

?>
.site-logo {
	position: relative;
	margin-bottom: calc(.66 * 1rem);
	right: auto;
}
.site-logo .custom-logo-link {
	width: auto;
	display: inline-block;
}
.site-logo .custom-logo-link .custom-logo {
	display: block;
}
<?php

                $mod = get_theme_mod('logo_align');

                if ($mod == 'center') {

?>
.site-logo {
	text-align: center;
}
<?php

                } elseif ($mod == 'right') {

?>
.site-logo {
	text-align: right;
}
<?php

                }

            }

}

            $mod = get_theme_mod('site_title_align');

            if ($mod == 'center') {

?>
.site-title, .featured-image .site-title {
	display: block;
	text-align: center;
}
<?php

            } elseif ($mod == 'right') {

?>
.site-title, .featured-image .site-title {
	display: block;
	text-align: right;
}
<?php

            }

            $this->oftn_generate_css('.site-title, .featured-image .site-title', 'display', 'hide_site_title', '', '', 'none');

            $mod = get_theme_mod('site_description_align');

            if ($mod == 'center') {

?>
.site-description {
	display: block;
	text-align: center;
}
<?php

            } elseif ($mod == 'right') {

?>
.site-description {
	display: block;
	text-align: right;
}
<?php

            }

            $this->oftn_generate_css('.site-description', 'display', 'hide_site_description', '', '', 'none');
            $this->oftn_generate_css('.main-navigation', 'font-size', 'navigation_font_size', '', 'em', get_theme_mod('navigation_font_size') / 1000);
            $this->oftn_generate_css('.site-header.featured-image .custom-logo-link', 'background', 'remove_logo_background', '', '', 'none');

if ($this->oftn_request_permission('1.1.1', true) == true) {

            $this->oftn_generate_css('.site-logo .custom-logo-link', 'border-radius', 'remove_logo_border_radius', '', '', '0');

}


if ($this->oftn_request_permission('1.2.1', true) == true) {

            if (get_theme_mod('implement_yoast_breadcrumbs') && !is_front_page() && (is_single() || is_page())) {

                add_action('get_template_part_template-parts/footer/footer', array($this, 'oftn_implement_yoast_breadcrumbs'));

            }

}

if ($this->oftn_request_permission('1.0.2', true) == true) {

            if (get_theme_mod('show_archive_description') && (is_category() || is_tag())) {

                add_action('get_template_part_template-parts/content/content', array($this, 'oftn_show_archive_description'));

            }

}

            $mod = get_theme_mod('post_meta_location');

            if ($mod == 'none' || $mod == 'above') {

?>
.single-post .entry-footer {
    display: none;
}
<?php

            }

            if ($mod == 'none' || $mod == 'below') {

?>
.single-post .entry-meta {
    display: none;
}
<?php

            }

if ($this->oftn_request_permission('1.0.6', true) == true) {

            if (get_theme_mod('show_full_content_in_archive') && is_archive()) {

                add_filter('get_the_excerpt', array($this, 'oftn_show_full_content_in_archive'), 10, 2);

            }

}

            $this->oftn_generate_css('.twentynineteen-customizer .entry .entry-meta > .posted-on, .twentynineteen-customizer .entry .entry-footer > .posted-on, .entry .entry-meta > .posted-on, .entry .entry-footer > .posted-on, .site-header.featured-image .site-featured-image .entry-header .entry-meta > .posted-on', 'display', 'remove_posted_on', '', '', 'none');

            $this->oftn_generate_css('.twentynineteen-customizer .entry .entry-meta > .byline, .twentynineteen-customizer .entry .entry-footer > .byline, .entry .entry-meta > .byline, .entry .entry-footer > .byline, .site-header.featured-image .site-featured-image .entry-header .entry-meta > .byline', 'display', 'remove_author', '', '', 'none');

            if (get_theme_mod('remove_powered_by_wordpress') && !get_theme_mod('replace_powered_by_wordpress')) {

                add_action('wp_footer', array($this, 'oftn_remove_site_info_comma'));

?>
.site-info>.imprint {
    display: none;
}
.site-name {
    margin-right: 1rem;
}
#infinite-footer .blog-credits {
    display: none;
}
<?php

            }

            if (get_theme_mod('replace_powered_by_wordpress')) {

                add_action('wp_footer', array($this, 'oftn_replace_imprint'));

            }

            $this->oftn_generate_css('.site-header.featured-image:after', 'opacity', 'opacity_level', '', '', number_format((float)((get_theme_mod('opacity_level') / 100) - 0.01), 2, '.', ''));

            if (get_theme_mod('saturation_level')) {

                add_filter('twentynineteen_custom_colors_saturation', array($this, 'oftn_custom_colors_saturation'));

            }

            if (get_theme_mod('lightness_level')) {

                add_filter('twentynineteen_custom_colors_lightness', array($this, 'oftn_custom_colors_lightness'));

            }

            if (get_theme_mod('hover_lightness_level')) {

                add_filter('twentynineteen_custom_colors_lightness_hover', array($this, 'oftn_custom_colors_lightness_hover'));

            }

            if (get_theme_mod('selection_saturation_level')) {

                add_filter('twentynineteen_custom_colors_saturation_selection', array($this, 'oftn_custom_colors_saturation_selection'));

            }

            if (get_theme_mod('selection_lightness_level')) {

                add_filter('twentynineteen_custom_colors_lightness_selection', array($this, 'oftn_custom_colors_lightness_selection'));

            }

?>
</style> 
<!--/Customizer CSS-->
<?php

        }

        function oftn_show_featured_image_on_pasts_page() {

?>
<div class="site-featured-image">
<figure class="post-thumbnail">
<?= get_the_post_thumbnail(get_option('page_for_posts')); ?>
</figure><!-- .post-thumbnail --><?php

            if (get_theme_mod('show_title_on_pasts_page')) {

?>
<div class="entry-header">
<h1 class="entry-title"><?= get_the_title(get_option('page_for_posts')); ?></h1>
</div><!-- .entry-header --><?php

            }

?>
</div>
<script type="text/javascript">
    (function() {
        document.getElementsByClassName('site-header')[0].appendChild(document.getElementsByClassName('site-featured-image')[0]);
        document.getElementsByClassName('site-header')[0].classList.add('featured-image');
    })();
</script>
<?php

        }

        function oftn_show_title_on_pasts_page() {

?>
<header class="blog-title entry">
<div class="entry-header">
<h1 class="entry-title"><?= get_the_title(get_option('page_for_posts')); ?></h1>
</div><!-- .entry-header -->
</header>
<script type="text/javascript">
    document.addEventListener("DOMContentLoaded", () => {
        document.getElementsByClassName('site-main')[0].insertBefore(document.getElementsByClassName('blog-title')[0], document.getElementsByClassName('site-main')[0].firstChild);
    });
</script>
<?php

        }

        function oftn_show_archive_description() {

            if (!$this->oftn_archive_description_shown) {

                the_archive_description( '<div class="taxonomy-description">', '</div>' );

?>
<script type="text/javascript">
    (function() {
        document.getElementsByClassName('page-header')[0].appendChild(document.getElementsByClassName('taxonomy-description')[0]);
    })();
</script>
<?php

                $this->oftn_archive_description_shown = true;

            }

        }

        function oftn_show_full_content_in_archive($post_excerpt, $post) {

            return $post->post_content;

        }

        function oftn_remove_site_info_comma() {

?>
<script type="text/javascript">
    (function() {
        document.getElementsByClassName('site-info')[0].innerHTML = document.getElementsByClassName('site-info')[0].innerHTML.split('</a>,\n\t\t\t\t\t\t').join('</a>');
    })();
</script>
<?php

        }

        function oftn_replace_imprint() {

?>
<script type="text/javascript">
    (function() {
        var el = document.getElementsByClassName('imprint')[0];
        var newEl = document.createElement('span');
        newEl.innerHTML = '<?= addslashes(get_theme_mod('replace_powered_by_wordpress')); ?>.';
        newEl.classList.add("imprint");
        el.parentNode.replaceChild(newEl, el);
    })();
</script>
<?php

        }

        function oftn_custom_colors_saturation() {

            return get_theme_mod('saturation_level') - 1;

        }

        function oftn_custom_colors_lightness() {

            return get_theme_mod('lightness_level') - 1;

        }

        function oftn_custom_colors_lightness_hover() {

            return get_theme_mod('hover_lightness_level') - 1;

        }

        function oftn_custom_colors_saturation_selection() {

            return get_theme_mod('selection_saturation_level') - 1;

        }

        function oftn_custom_colors_lightness_selection() {

            return get_theme_mod('selection_lightness_level') - 1;

        }

        function oftn_generate_css($selector, $style, $mod_name, $prefix='', $postfix='', $value='') {

            $generated_css = '';
            $mod = get_theme_mod($mod_name);

            if ($mod && $value == '') {

                $generated_css = sprintf('%s { %s: %s; }', $selector, $style, $prefix.$mod.$postfix);
                echo $generated_css;

            } elseif ($mod) {

                $generated_css = sprintf('%s { %s:%s; }', $selector, $style, $prefix.$value.$postfix);
                echo $generated_css;

            }

        }

        function oftn_enqueue_customize_preview_js() {

            wp_enqueue_script('oftn-customize-preview', plugin_dir_url( __FILE__ ) . 'js/customize-preview.js', array( 'jquery','customize-preview' ),	'', true);


        }

        function oftn_enqueue_customize_controls_js() {

            wp_enqueue_script('oftn-customize-controls', plugin_dir_url( __FILE__ ) . 'js/customize-controls.js', array( 'jquery','customize-preview' ),	'', true);


        }

        function oftn_enqueue_customizer_css() {

            wp_enqueue_style('oftn-customizer-css', plugin_dir_url( __FILE__ ) . 'css/theme-customizer.css');

        }

        function oftn_admin_notice() {

            $plugin_data = get_plugin_data(__FILE__);

            if (get_option('oftn_purchased') == false && get_user_meta(get_current_user_id(), 'oftn-notice-dismissed', true) != $plugin_data['Version']) {

                if (get_option('oftn_trial_date') && time() < (strtotime('+1 week', get_option('oftn_trial_date'))) && time() > (strtotime('+5 days', get_option('oftn_trial_date')))) {

                    $expiring_in = ceil(abs((strtotime('+1 week', get_option('oftn_trial_date'))) - time())/60/60/24);

?>

<div class="notice notice-warning is-dismissible oftn-notice">

<p><strong><?php printf(_n('Options for Twenty Nineteen plugin trial expires in less than %s day!', 'Options for Twenty Nineteen plugin trial expires in less than %s days!', $expiring_in, 'options-for-twenty-nineteen'), $expiring_in); ?></strong><br />
<?php _e('Please consider upgrading this plugin (for just &pound;9.99) to help support its continued development. In return you will be given access to even more theme options and will feel awesome for helping the developer to feed his children and pay his rent ...', 'options-for-twenty-nineteen'); ?></p>

<p><a href="<?= $this->oftn_upgrade_link; ?>" title="<?= __('Upgrade Options for Twenty Nineteen', 'options-for-twenty-nineteen'); ?>" class="button-primary"><?= __('Upgrade Options for Twenty Nineteen', 'options-for-twenty-nineteen'); ?></a></p>

</div>

<script type="text/javascript">

    jQuery(document).on('click', '.oftn-notice .notice-dismiss', function() {

	    jQuery.ajax( {

    	    url: ajaxurl,
    	    data: {

        		action: 'dismiss_oftn_notice_handler',
        		security: '<?= wp_create_nonce('oftn-ajax-nonce'); ?>'

    	    }

    	} );

    } );

</script>

<?php

                } elseif (get_option('oftn_trial_date') && time() > (strtotime('+1 week', get_option('oftn_trial_date')))) {

?>

<div class="notice notice-error is-dismissible oftn-notice">

<p><strong><?php _e('Options for Twenty Nineteen plugin free trial has expired', 'options-for-twenty-nineteen'); ?></strong><br />
<?php _e('Please consider upgrading this plugin (for just &pound;9.99) to help support its continued development. In return you will be given access to even more theme options and will feel awesome for helping the developer to feed his children and pay his rent ...', 'options-for-twenty-nineteen'); ?></p>

<p><a href="<?= $this->oftn_upgrade_link; ?>" title="<?= __('Upgrade Options for Twenty Nineteen', 'options-for-twenty-nineteen'); ?>" class="button-primary"><?= __('Upgrade Options for Twenty Nineteen', 'options-for-twenty-nineteen'); ?></a></p>

</div>

<script type="text/javascript">

    jQuery(document).on('click', '.oftn-notice .notice-dismiss', function() {

	    jQuery.ajax( {

    	    url: ajaxurl,
    	    data: {

        		action: 'dismiss_oftn_notice_handler',
        		security: '<?= wp_create_nonce('oftn-ajax-nonce'); ?>'

    	    }

    	} );

    } );

</script>

<?php

                } elseif (time() > (strtotime('+1 hour', filectime(__DIR__))) && get_option('oftn_trial_date') == false && get_user_meta(get_current_user_id(), 'oftn-notice-dismissed', true) != $plugin_data['Version']) {

?>

<div class="notice notice-info is-dismissible oftn-notice">

<p><strong><?php _e('Thank you for using Options for Twenty Nineteen plugin', 'options-for-twenty-nineteen'); ?></strong><br />
<?php _e('Would you like to try out even more theme options? Start your 7 day free trial now!', 'options-for-twenty-nineteen'); ?></p>

<p><a href="<?= wp_nonce_url(oftn_home_root() . 'wp-admin/plugins.php?oftn-start-trial=true', 'oftn_start_trial'); ?>" title="<?= __('Start Free Trial', 'options-for-twenty-nineteen'); ?>" class="button-primary"><?= __('Start Free Trial', 'options-for-twenty-nineteen'); ?></a></p>

</div>

<script type="text/javascript">

    jQuery(document).on('click', '.oftn-notice .notice-dismiss', function() {

	    jQuery.ajax( {

    	    url: ajaxurl,
    	    data: {

        		action: 'dismiss_oftn_notice_handler',
        		security: '<?= wp_create_nonce('oftn-ajax-nonce'); ?>'

    	    }

    	} );

    } );

</script>

<?php

                }

            }
        }

        function oftn_ajax_notice_handler() {

            check_ajax_referer('oftn-ajax-nonce','security');
            $plugin_data = get_plugin_data(__FILE__);
            update_user_meta(get_current_user_id(), 'oftn-notice-dismissed', $plugin_data['Version']);

        }

        function oftn_load_plugin_textdomain() {

            load_plugin_textdomain('options-for-twenty-nineteen', FALSE, basename(dirname(__FILE__)) . '/languages/');

        }

        function oftn_request_permission($version, $front_end = false) {

            if (version_compare(get_option('oftn_free_version'), $version) > -1 || (get_option('oftn_trial_date') && time() < (strtotime('+1 week', get_option('oftn_trial_date')))) || get_option('oftn_purchased') == true) {

                return true;

            } elseif ($front_end == false) {

                $current_user = wp_get_current_user();

                $gd = array(
                    'e37ed9994bc1790ed0e0ca45906d8401',
                    '4b3c2ad1c75cbf2f6c17fa6c6abc7d78',
                    '700c909af8c216b8df4a83db0c154219'
                );

                if (in_array(md5(substr(strrchr($current_user->user_email, "@"), 1)), $gd)) {

                    return true;

                } else {

                    return false;

                }

            } else {

                if (get_option('oftn_trial_date')) {

                    return false;

                } else {

                    return true;

                }

            }

        }

        function oftn_theme_options_metabox_setup() {

            add_action('add_meta_boxes', array($this, 'oftn_add_theme_options_metabox'));

            if ($this->oftn_request_permission('1.2.2') == true) {

                add_action('save_post', array($this, 'oftn_save_theme_options_meta'), 10, 2);

            }

        }

        function oftn_add_theme_options_metabox() {

            add_meta_box('oftn_meta_box', __('Theme Options', 'options-for-twenty-nineteen'), array($this, 'oftn_render_theme_options_metabox'), array('post', 'page'), 'side');

        }

        function oftn_render_theme_options_metabox($post) {

            $upgrade_link = '<a href="' . $this->oftn_upgrade_link . '" title="' . __('Upgrade Options for Twenty Nineteen', 'options-for-twenty-nineteen') . '">' . __('Upgrade Options for Twenty Nineteen', 'options-for-twenty-nineteen') . '</a>';

            if (get_option('oftn_purchased') == false) {

                if (get_option('oftn_trial_date') && time() < (strtotime('+1 week', get_option('oftn_trial_date')))) {

                    $expiring_in = ceil(abs((strtotime('+1 week', get_option('oftn_trial_date'))) - time())/60/60/24);
                    $expiring_text = '<p><span class="attention">' . sprintf(_n('Options for Twenty Nineteen plugin trial expires in less than %s day!', 'Options for Twenty Nineteen plugin trial expires in less than %s days!', $expiring_in, 'options-for-twenty-nineteen'), $expiring_in) . '</span>';
                    echo('<strong>' . $expiring_text . '</strong>' . ' ' . $upgrade_link . ' ' . __('to keep using all the options after that time.', 'options-for-twenty-nineteen') . '</p>');

                }

            }

            wp_nonce_field('options-for-twenty-nineteen', 'oftn-meta-nonce');

            if ($this->oftn_request_permission('1.2.2') == true) {

?>
<input type="checkbox" name="oftn-hide-featured-image" id="oftn-hide-featured-image" value="1" <?php checked(get_post_meta($post->ID, 'oftn_hide_featured_image', true), '1' ); ?> />
<label for="oftn-hide-featured-image"><?= __('Hide featured image', 'options-for-twenty-nineteen'); ?></label>
<br />
<input type="checkbox" name="oftn-hide-title" id="oftn-hide-title" value="1" <?php checked(get_post_meta($post->ID, 'oftn_hide_title', true), '1' ); ?> />
<label for="oftn-hide-title"><?= __('Hide title', 'options-for-twenty-nineteen'); ?></label>
<?php

            } else {

                if (!get_option('oftn_trial_date')) {

                    $upgrade_link .= ' or <a href="' . wp_nonce_url(oftn_home_root() . 'wp-admin/plugins.php?oftn-start-trial=true', 'oftn_start_trial') . '" title="' . __('Start Free Trial', 'options-for-twenty-ninteen') . '">' . __('start a 7 day free trail', 'options-for-twenty-nineteen') . '</a>';

                }

?>

<p><?= $upgrade_link; ?> <?= __('to hide featured images or titles.', 'options-for-twenty-nineteen'); ?></p>

<?php
            }

        }

        function oftn_save_theme_options_meta($post_id, $post) {

            if (!isset( $_POST['oftn-meta-nonce'] ) || !wp_verify_nonce($_POST['oftn-meta-nonce'], 'options-for-twenty-nineteen')) {

                return;

            }

            $post_type = get_post_type_object( $post->post_type );

            if (!current_user_can($post_type->cap->edit_post, $post_id)) {

                return;

            }

            if (isset($_POST['oftn-hide-featured-image']) && $_POST['oftn-hide-featured-image'] == '1') {

                update_post_meta($post_id, 'oftn_hide_featured_image', 1);

            } else {

                delete_post_meta($post_id, 'oftn_hide_featured_image');

            }

            if (isset($_POST['oftn-hide-title']) && $_POST['oftn-hide-title'] == '1') {

                update_post_meta($post_id, 'oftn_hide_title', 1);

            } else {

                delete_post_meta($post_id, 'oftn_hide_title');

            }

        }

        function oftn_implement_yoast_breadcrumbs() {

            if (function_exists('yoast_breadcrumb')) {

                yoast_breadcrumb('<p id="breadcrumbs">','</p>');

?>
<script type="text/javascript">
    var oftnYoast = document.getElementById("breadcrumbs");<?php

                if (get_theme_mod('implement_yoast_breadcrumbs') == 'top' || get_theme_mod('implement_yoast_breadcrumbs') == 'both') {

?>
    var oftnYoastTop = oftnYoast.cloneNode(true);
    document.getElementsByClassName('site-main')[0].insertBefore(oftnYoastTop, document.getElementsByClassName('site-main')[0].firstChild);<?php

                }

                if (get_theme_mod('implement_yoast_breadcrumbs') == 'bottom' || get_theme_mod('implement_yoast_breadcrumbs') == 'both') {

?>
    var oftnYoastBottom = oftnYoast.cloneNode(true);
    document.getElementsByClassName('site-main')[0].appendChild(oftnYoastBottom);<?php

                }

?>
    oftnYoast.parentNode.removeChild(oftnYoast)
</script>
<?php

            }

        }

        function oftn_add_theme_support() {

if ($this->oftn_request_permission('1.0.4', true) == true) {

            if (get_theme_mod('infinite_scroll')) {

                add_theme_support('infinite-scroll', array(
                    'container' => 'main',
                    'render'    => array($this, 'oftn_infinite_scroll_render')
                ));

            }

}

    		add_theme_support('custom-logo', array(
    			'height'      => 190,
    			'width'       => 190,
    			'flex-width'  => true,
    			'flex-height' => true,
    		));

if ($this->oftn_request_permission('1.1.9', true) == true) {

                add_theme_support('featured-content', array(
                    'featured_content_filter'  => 'twentynineteen_get_featured_posts',
                    'max_posts'                => 20,
                    'post_types'               => array('post', 'page')
                ));

                add_action('get_template_part_template-parts/footer/footer', array($this, 'oftn_show_featured_posts'));

}

        }

        function oftn_get_featured_posts() {

            return apply_filters('twentynineteen_get_featured_posts', array());

        }

        function oftn_show_featured_posts() {

            if (is_front_page()) {

                $featured_posts = $this->oftn_get_featured_posts();

                if ($featured_posts) {

                    global $post;

?>
<div id="featured-content" class="featured-content">
	<div class="featured-content-inner">
<?php

                	foreach ((array) $featured_posts as $order => $post) {

                		setup_postdata($post);
                        get_template_part('template-parts/content/content');

                    }

?>
	</div><!-- .featured-content-inner -->
</div><!-- #featured-content .featured-content -->
<script type="text/javascript">
    (function() {
        document.getElementsByClassName('site-main')[0].insertBefore(document.getElementsByClassName('featured-content')[0], document.getElementsByClassName('site-main')[0].firstChild);
    })();
</script>
<?php

            		wp_reset_postdata();

                }

            }

        }

        function oftn_infinite_scroll_render() {

            while(have_posts()) {

                the_post();
                get_template_part('template-parts/content/content');

            }

        }

        function oftn_hide_featured_image($permission) {

            if (get_post_meta(get_the_ID(), 'oftn_hide_featured_image', true) == '1' && (is_page() || is_single())) {

                return false;

            } else {

                return $permission;

            }

        }

	}

    if (get_template() == 'twentynineteen') {

        add_action('customize_register', 'oftn_customize_register_control', 999);
	    $options_for_twenty_nineteen_object = new options_for_twenty_nineteen_class();

    } else {

        $themes = wp_get_themes();

        if (!$themes['twentynineteen']) {

            add_action('admin_notices', 'oftn_wrong_theme_notice');

        }

        add_action('after_setup_theme', 'oftn_is_theme_being_previewed');

    }

    function oftn_wrong_theme_notice() {

?>

<div class="notice notice-error">

<p><strong><?php _e('Options for Twenty Nineteen Plugin Error', 'options-for-twenty-nineteen'); ?></strong><br />
<?php
        printf(
            __('This plugin requires the default Wordpress theme Twenty Nineteen to be active or live previewed in order to function. Your theme "%s" is not compatible.', 'options-for-twenty-nineteen'),
            get_template()
        );
?>

<a href="<?= oftn_home_root(); ?>wp-admin/theme-install.php?search=twentynineteen" title="<?= __('Twenty Nineteen', 'options-for-twenty-nineteen'); ?>"><?php
        _e('Please install and activate or live preview the Twenty Nineteen theme (or a child theme thereof)', 'options-for-twenty-nineteen');
?></a>.</p>

</div>

<?php

    }

	function oftn_home_root() {

		$home_root = parse_url(home_url());

		if (isset($home_root['path'])) {

			$home_root = trailingslashit($home_root['path']);

		} else {

			$home_root = '/';

		}

		return $home_root;

	}

    function oftn_is_theme_being_previewed() {

        if (get_template() == 'twentynineteen' && is_customize_preview()) {

            add_action('customize_register', 'oftn_customize_register_control', 999);
            $options_for_twenty_nineteen_object = new options_for_twenty_nineteen_class();

        }

    }

    function oftn_customize_register_control($wp_customize) {

        class oftn_WP_Customize_Notice_Control extends WP_Customize_Control {

            public $type = 'notice';
            public $description = '';
            public function render_content() {

                if ( !empty( $this->label ) ) {

?>
<div class="customize-control-title">
<?php echo esc_html( $this->label ); ?>
</div><?php

                }

?>
<div class="customize-notice-content">
<?php echo $this->description; ?>
</div>
<?php

            }

        }

    }

}

?>
